"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var graphql_transformer_core_1 = require("graphql-transformer-core");
var AutoTransformer_1 = require("../AutoTransformer");
var graphql_dynamodb_transformer_1 = require("graphql-dynamodb-transformer");
var getInputType = function (schemaDoc) { return function (name) {
    return schemaDoc.definitions.find(function (d) { return d.kind === graphql_1.Kind.INPUT_OBJECT_TYPE_DEFINITION && d.name.value === name; });
}; };
var getInputField = function (input, field) { var _a; return (_a = input.fields) === null || _a === void 0 ? void 0 : _a.find(function (f) { return f.name.value === field; }); };
var getType = function (schemaDoc) { return function (name) {
    return schemaDoc.definitions.find(function (d) { return d.kind === graphql_1.Kind.OBJECT_TYPE_DEFINITION && d.name.value === name; });
}; };
var getField = function (input, field) { var _a; return (_a = input.fields) === null || _a === void 0 ? void 0 : _a.find(function (f) { return f.name.value === field; }); };
var typeToString = function (t) {
    if (!t) {
        return '<undefined>';
    }
    switch (t.kind) {
        case 'NamedType':
            return t.name.value;
        case 'ListType':
            return "[" + typeToString(t.type) + "]";
        case 'NonNullType':
            return typeToString(t.type) + "!";
    }
};
test('@auto strip target field of CreateXXXInput and UpdateXXXInput', function () {
    var _a;
    var validSchema = "\n    type Post @model {\n        id: ID!\n        title: String!\n        createdAt: String! @auto\n    }\n    ";
    var transformer = new graphql_transformer_core_1.GraphQLTransform({
        transformers: [new graphql_dynamodb_transformer_1.DynamoDBModelTransformer(), new AutoTransformer_1.AutoTransformer()],
    });
    var out = transformer.transform(validSchema);
    var schemaDoc = graphql_1.parse(out.schema);
    expect(out).toBeDefined();
    expect(typeToString((_a = getField(getType(schemaDoc)('Post'), 'createdAt')) === null || _a === void 0 ? void 0 : _a.type)).toBe('String!');
    expect(getInputField(getInputType(schemaDoc)('CreatePostInput'), 'createdAt')).toBeUndefined();
    expect(getInputField(getInputType(schemaDoc)('UpdatePostInput'), 'createdAt')).toBeUndefined();
});
test('@auto(creatable: true) strip target field of UpdateXXXInput', function () {
    var _a, _b;
    var validSchema = "\n    type Post @model {\n        id: ID!\n        title: String!\n        createdAt: String! @auto(creatable: true)\n    }\n    ";
    var transformer = new graphql_transformer_core_1.GraphQLTransform({
        transformers: [new graphql_dynamodb_transformer_1.DynamoDBModelTransformer(), new AutoTransformer_1.AutoTransformer()],
    });
    var out = transformer.transform(validSchema);
    var schemaDoc = graphql_1.parse(out.schema);
    expect(out).toBeDefined();
    expect(typeToString((_a = getField(getType(schemaDoc)('Post'), 'createdAt')) === null || _a === void 0 ? void 0 : _a.type)).toBe('String!');
    expect(typeToString((_b = getInputField(getInputType(schemaDoc)('CreatePostInput'), 'createdAt')) === null || _b === void 0 ? void 0 : _b.type)).toBe('String');
    expect(getInputField(getInputType(schemaDoc)('UpdatePostInput'), 'createdAt')).toBeUndefined();
});
test('@auto fails without @model.', function () {
    var validSchema = "\n    type Post {\n        id: ID!\n        title: String!\n        version: String!\n        createdAt: String! @auto\n    }\n    ";
    try {
        var transformer = new graphql_transformer_core_1.GraphQLTransform({
            transformers: [new graphql_dynamodb_transformer_1.DynamoDBModelTransformer(), new AutoTransformer_1.AutoTransformer()],
        });
        transformer.transform(validSchema);
    }
    catch (e) {
        expect(e.name).toEqual('InvalidDirectiveError');
    }
});
test('@auto fails when target field is nullable.', function () {
    var validSchema = "\n    type Post @model {\n        id: ID!\n        title: String!\n        version: String!\n        createdAt: String @auto\n    }\n    ";
    try {
        var transformer = new graphql_transformer_core_1.GraphQLTransform({
            transformers: [new graphql_dynamodb_transformer_1.DynamoDBModelTransformer(), new AutoTransformer_1.AutoTransformer()],
        });
        transformer.transform(validSchema);
    }
    catch (e) {
        expect(e.name).toEqual('TransformerContractError');
    }
});
//# sourceMappingURL=AutoTransformer.test.js.map